%define major   1.5
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           srt
Version:        1.5.4
Release:        %mkrel 1
Summary:        Secure Reliable Transport (SRT) protocol tools
Group:          System/Libraries
License:        MPLv2.0
URL:            https://www.srtalliance.org
Source0:        https://github.com/Haivision/srt/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(nettle)

%description
Secure Reliable Transport (SRT) is an open source transport technology that
optimizes streaming performance across unpredictable networks, such as
the Internet.

%package -n %{libname}
Summary:        Secure Reliable Transport (SRT) protocol libraries
Group:          System/Libraries

%description -n %{libname}
This package contains a shared system library for Secure Reliable
Transport (SRT).

%package -n %{devname}
Summary:        Development files for the Secure Reliable Transport (SRT) library
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains all necessary include files and libraries
needed to develop applications with Secure Reliable Transport
(SRT) support.


%prep
%autosetup -p1

%build
%cmake \
  -DENABLE_STATIC=OFF \
  -DENABLE_UNITTESTS=ON \
  -DENABLE_GETNAMEINFO=ON \
  -DENABLE_BONDING=ON \
  -DENABLE_PKTINFO=ON \
  -DUSE_ENCLIB=gnutls

%cmake_build

%install
%cmake_install

# remove old upstream temporary compatibility pc
rm -f %{buildroot}%{_libdir}/pkgconfig/haisrt.pc

%check
# - TestIPv6 are known broken due to v4_v6 mapping differnces between platforms
#   https://github.com/Haivision/srt/issues/1972#
%ctest -j1 -E TestIPv6

%files
%license LICENSE
%doc README.md docs
%{_bindir}/srt-ffplay
%{_bindir}/srt-file-transmit
%{_bindir}/srt-live-transmit
%{_bindir}/srt-tunnel

%files -n %{libname}
%license LICENSE
%{_libdir}/libsrt.so.%{major}{,.*}

%files -n %{devname}
%doc examples
%{_includedir}/srt/
%{_libdir}/libsrt.so
%{_libdir}/pkgconfig/srt.pc


%changelog
* Thu Nov 14 2024 daviddavid <daviddavid> 1.5.4-1.mga10
+ Revision: 2115147
- new version: 1.5.4

* Sun Apr 14 2024 wally <wally> 1.5.3-2.mga10
+ Revision: 2057354
- rebuild for missing source pkg

* Tue Apr 09 2024 daviddavid <daviddavid> 1.5.3-1.mga10
+ Revision: 2056233
- initial package srt (for vlc)

